@@ -36,23 +36,27 @@ import six
 
 # Date
 
+
 def date_to_json(value, obj):
     if value is None:
         return value
     else:
-        # Droping microseconds and only keeping milliseconds to conform
+        # Dropping microseconds and only keeping milliseconds to conform
         # with JavaScript's Data.toJSON's behavior - and prevent bouncing
         # back updates from the front-end.
         return value.strftime('%Y-%m-%dT%H:%M:%S.%f')[:-3] + 'Z'
 
+
 def date_from_json(value, obj):
     if value:
         return dt.datetime.strptime(value.rstrip('Z'), '%Y-%m-%dT%H:%M:%S.%f')
     else:
         return value
 
+
 date_serialization = dict(to_json=date_to_json, from_json=date_from_json)
 
+
 class Date(TraitType):
 
     """
@@ -79,9 +83,7 @@ class Date(TraitType):
         self.error(obj, value)
 
     def __init__(self, default_value=dt.datetime.today(), **kwargs):
-        args = (default_value,)
-        self.default_value = default_value
-        super(Date, self).__init__(args=args, **kwargs)
+        super(Date, self).__init__(default_value=default_value, **kwargs)
         self.tag(**date_serialization)
 
 
@@ -105,20 +107,16 @@ def convert_to_date(array, fmt='%m-%d-%Y'):
             for elem in array:
                 temp_val = pd.to_datetime(
                     elem, errors='coerce', infer_datetime_format=True)
-                temp_val = elem if (
-                    temp_val[0] == np.datetime64('NaT')) else temp_val
+                temp_val = elem if isinstance(temp_val[0], type(pd.NaT)) else temp_val
                 return_value.append(temp_val)
         elif(isinstance(array, list)):
             temp_val = pd.to_datetime(
                 array, errors='coerce', infer_datetime_format=True)
-            return_value = array if (
-                temp_val[0] == np.datetime64('NaT')) else temp_val
+            return_value = array if isinstance(temp_val[0], type(pd.NaT)) else temp_val
         else:
             temp_val = pd.to_datetime(
                 array, errors='coerce', infer_datetime_format=True)
-            temp_val = array if (
-                temp_val[0] == np.datetime64('NaT')) else temp_val
-            return_value = temp_val
+            return_value = array if isinstance(temp_val[0], type(pd.NaT)) else temp_val
         return return_value
     elif(isinstance(array, np.ndarray)):
         warnings.warn("Array could not be converted into a date")
@@ -130,8 +128,16 @@ def array_from_json(value, obj=None):
         # this will accept regular json data, like an array of values, which can be useful it you want
         # to link bqplot to other libraries that use that
         if isinstance(value, list):
-            if len(value) > 0 and isinstance(value[0], dict) and 'value' in value[0]:
-                return np.array([array_from_json(k) for k in value])
+            if len(value) > 0 and (isinstance(value[0], dict) and 'value' in value[0]):
+                subarrays = [array_from_json(k) for k in value]
+                if len(subarrays) > 0:
+                    expected_length = len(subarrays[0])
+                    # if a 'ragged' array, we should explicitly pass dtype=object
+                    if any(len(k) != expected_length for k in subarrays[1:]):
+                        return np.array(subarrays, dtype=object)
+                return np.array(subarrays)
+            elif len(value) > 0 and isinstance(value[0], list):
+                return np.array(value, dtype=object)
             else:
                 return np.array(value)
         elif 'value' in value:
@@ -147,6 +153,7 @@ def array_from_json(value, obj=None):
                 ar = ar.astype('datetime64[ms]')
             return ar
 
+
 def array_to_json(ar, obj=None, force_contiguous=True):
     if ar is None:
         return None
@@ -196,28 +203,31 @@ def array_to_json(ar, obj=None, force_contiguous=True):
 
 array_serialization = dict(to_json=array_to_json, from_json=array_from_json)
 
+
 def array_squeeze(trait, value):
     if len(value.shape) > 1:
         return np.squeeze(value)
     else:
         return value
 
+
 def array_dimension_bounds(mindim=0, maxdim=np.inf):
     def validator(trait, value):
         dim = len(value.shape)
         if dim < mindim or dim > maxdim:
             raise TraitError('Dimension mismatch for trait %s of class %s: expected an \
-            array of dimension comprised in interval [%s, %s] and got an array of shape %s'\
-            % (trait.name, trait.this_class, mindim, maxdim, value.shape))
+                array of dimension comprised in interval [%s, %s] and got an array of shape %s' % (
+                trait.name, trait.this_class, mindim, maxdim, value.shape))
         return value
     return validator
 
+
 def array_supported_kinds(kinds='biufMSUO'):
     def validator(trait, value):
         if value.dtype.kind not in kinds:
             raise TraitError('Array type not supported for trait %s of class %s: expected a \
-            array of kind in list %r and got an array of type %s (kind %s)'\
-            % (trait.name, trait.this_class, list(kinds), value.dtype, value.dtype.kind))
+                array of kind in list %r and got an array of type %s (kind %s)' % (
+                trait.name, trait.this_class, list(kinds), value.dtype, value.dtype.kind))
         return value
     return validator
 
@@ -230,16 +240,21 @@ def dataframe_from_json(value, obj):
     else:
         return pd.DataFrame(value)
 
+
 def dataframe_to_json(df, obj):
     if df is None:
         return None
     else:
-        return df.to_dict(orient='records')
+        # Replacing NaNs with None as it's not valid JSON
+        cleandf = df.fillna(np.nan).replace([np.nan], [None])
+        return cleandf.to_dict(orient='records')
+
 
 dataframe_serialization = dict(to_json=dataframe_to_json, from_json=dataframe_from_json)
 
 # dataframe validators
 
+
 def dataframe_warn_indexname(trait, value):
     if value.index.name is not None:
         warnings.warn("The '%s' dataframe trait of the %s instance disregards the index name" % (trait.name, trait.this_class))
@@ -248,14 +263,18 @@ def dataframe_warn_indexname(trait, value):
 
 # Series
 
+
 def series_from_json(value, obj):
     return pd.Series(value)
 
+
 def series_to_json(value, obj):
     return value.to_dict()
 
+
 series_serialization = dict(to_json=series_to_json, from_json=series_from_json)
 
+
 def _array_equal(a, b):
     """Really tests if arrays are equal, where nan == nan == True"""
     try:
